@@ -85,6 +85,8 @@ __PACKAGE__->add_columns(
   { data_type => "boolean", is_nullable => 0, default_value => \"false" },
   "pae_is_enabled",
   { data_type => "boolean", is_nullable => 1 },
+  "custom_fields",
+  { data_type => "jsonb", is_nullable => 0, default_value => \"{}" },
 );
 __PACKAGE__->set_primary_key("ip");
 
