@@ -20,7 +20,7 @@ get '/ajax/content/device/ports' => require_login sub {
 
     my $device = schema(vars->{'tenant'})->resultset('Device')
       ->search_for_device($q) or send_error('Bad device', 400);
-    my $set = $device->ports->with_properties;
+    my $set = $device->ports->with_properties->with_custom_fields;
 
     # refine by ports if requested
     my $f = param('f');
